package javax.xml.crypto.dsig.keyinfo;

import javax.xml.crypto.MarshalException;
import javax.xml.crypto.XMLStructure;
import javax.xml.crypto.URIDereferencer;
import java.math.BigInteger;
import java.security.KeyException;
import java.security.PublicKey;
import java.util.List;
import java.security.NoSuchProviderException;
import java.security.NoSuchAlgorithmException;
import javax.xml.crypto.NoSuchMechanismException;
import sun.security.jca.GetInstance;
import java.security.Provider;

public abstract class KeyInfoFactory
{
    private String mechanismType;
    private Provider provider;
    
    protected KeyInfoFactory() {
    }
    
    public static KeyInfoFactory getInstance(String s) {
        if (s == null) {
            throw new NullPointerException("mechanismType cannot be null");
        }
        GetInstance.Instance instance;
        try {
            instance = GetInstance.getInstance("KeyInfoFactory", null, s);
        }
        catch (NoSuchAlgorithmException cause) {
            throw new NoSuchMechanismException(cause);
        }
        KeyInfoFactory keyInfoFactory = (KeyInfoFactory)instance.impl;
        keyInfoFactory.mechanismType = s;
        keyInfoFactory.provider = instance.provider;
        return keyInfoFactory;
    }
    
    public static KeyInfoFactory getInstance(String s, Provider provider) {
        if (s == null) {
            throw new NullPointerException("mechanismType cannot be null");
        }
        if (provider == null) {
            throw new NullPointerException("provider cannot be null");
        }
        GetInstance.Instance instance;
        try {
            instance = GetInstance.getInstance("KeyInfoFactory", null, s, provider);
        }
        catch (NoSuchAlgorithmException cause) {
            throw new NoSuchMechanismException(cause);
        }
        KeyInfoFactory keyInfoFactory = (KeyInfoFactory)instance.impl;
        keyInfoFactory.mechanismType = s;
        keyInfoFactory.provider = instance.provider;
        return keyInfoFactory;
    }
    
    public static KeyInfoFactory getInstance(String s, String provider) throws NoSuchProviderException {
        if (s == null) {
            throw new NullPointerException("mechanismType cannot be null");
        }
        if (provider == null) {
            throw new NullPointerException("provider cannot be null");
        }
        if (provider.length() == 0) {
            throw new NoSuchProviderException();
        }
        GetInstance.Instance instance;
        try {
            instance = GetInstance.getInstance("KeyInfoFactory", null, s, provider);
        }
        catch (NoSuchAlgorithmException cause) {
            throw new NoSuchMechanismException(cause);
        }
        KeyInfoFactory keyInfoFactory = (KeyInfoFactory)instance.impl;
        keyInfoFactory.mechanismType = s;
        keyInfoFactory.provider = instance.provider;
        return keyInfoFactory;
    }
    
    public static KeyInfoFactory getInstance() {
        return getInstance("DOM");
    }
    
    public final String getMechanismType() {
        return this.mechanismType;
    }
    
    public final Provider getProvider() {
        return this.provider;
    }
    
    public abstract KeyInfo newKeyInfo(List p0);
    
    public abstract KeyInfo newKeyInfo(List p0, String p1);
    
    public abstract KeyName newKeyName(String p0);
    
    public abstract KeyValue newKeyValue(PublicKey p0) throws KeyException;
    
    public abstract PGPData newPGPData(byte[] p0);
    
    public abstract PGPData newPGPData(byte[] p0, byte[] p1, List p2);
    
    public abstract PGPData newPGPData(byte[] p0, List p1);
    
    public abstract RetrievalMethod newRetrievalMethod(String p0);
    
    public abstract RetrievalMethod newRetrievalMethod(String p0, String p1, List p2);
    
    public abstract X509Data newX509Data(List p0);
    
    public abstract X509IssuerSerial newX509IssuerSerial(String p0, BigInteger p1);
    
    public abstract boolean isFeatureSupported(String p0);
    
    public abstract URIDereferencer getURIDereferencer();
    
    public abstract KeyInfo unmarshalKeyInfo(XMLStructure p0) throws MarshalException;
}
